mafw.processor
==============

.. automodule:: mafw.processor

   
   .. rubric:: Module Attributes

   .. autosummary::
   
      ParameterType
      F
   
   .. rubric:: Functions

   .. autosummary::
   
      ensure_parameter_registration
      validate_database_conf
   
   .. rubric:: Classes

   .. autosummary::
   
      ActiveParameter
      PassiveParameter
      Processor
      ProcessorList
      ProcessorMeta
   